<h1>{{ device.alias }}</h1>

<div>
    <label> {{ action.operation }} </label>
    <label> {{ action.request }} </label>
</div>

<div>
    <p> {{ action.response }} </p>
</div>

    <h2>Visualizations</h2>

<div>
    {% autoescape off %}{{ heatmap }}{% endautoescape %}

    {{ heatmap_error }}
</div>
<div>
    {% autoescape off %}{{ spectrum}}{% endautoescape %}

    {{ spectrum_error }}
</div>

<a href="{% url 'visaweb:detail' device.alias %}">Back to details</a>